@@ -1,3 +1,5 @@
+#![allow(unknown_lints)]
+#![allow(clippy::literal_string_with_formatting_args)]
 use std::fmt::{Display, Formatter};
 
 use crate::config::Settings;
